********
Pylians3
********

Many analyses of the CAMELS simulations have been carried out using the `Pylians3 <https://github.com/franciscovillaescusa/Pylians3>`_ libraries. Furthermore, the :ref:`CAMELS_library` requires Pylians3, so we encourage its usage to analyze CAMELS data. 
